@@ -1,22 +1,18 @@
 import numpy as np
 
-# guard against import of a non-existant metrics module in older skimage
+# guard against import of a non-existent metrics module in older skimage
 try:
     from skimage import metrics
 except ImportError:
     pass
 
 
-class SetMetricsSuite(object):
+class SetMetricsSuite:
     shape = (6, 6)
     coords_a = np.zeros(shape, dtype=bool)
     coords_b = np.zeros(shape, dtype=bool)
 
     def setup(self):
-        try:
-            from skimage.metrics import hausdorff_distance, hausdorff_pair
-        except ImportError:
-            raise NotImplementedError("Hausdorff metrics unavailable")
         points_a = (1, 0)
         points_b = (5, 2)
         self.coords_a[points_a] = True
@@ -25,5 +21,8 @@ class SetMetricsSuite(object):
     def time_hausdorff_distance(self):
         metrics.hausdorff_distance(self.coords_a, self.coords_b)
 
+    def time_modified_hausdorff_distance(self):
+        metrics.hausdorff_distance(self.coords_a, self.coords_b, method="modified")
+
     def time_hausdorff_pair(self):
         metrics.hausdorff_pair(self.coords_a, self.coords_b)
