@@ -5,9 +5,10 @@ See "Writing benchmarks" in the asv docs for more information.
 
 import numpy as np
 from numpy.lib import NumpyVersion as Version
+import scipy.ndimage
 
 import skimage
-from skimage import data, morphology, util
+from skimage import color, data, morphology, util
 
 
 class Skeletonize3d:
@@ -24,7 +25,7 @@ class Skeletonize3d:
         # we stack the horse data 5 times to get an example volume
         self.image = np.stack(5 * [util.invert(data.horse())])
 
-    def time_skeletonize_3d(self):
+    def time_skeletonize(self):
         self.skeletonize(self.image)
 
     def peakmem_reference(self, *args):
@@ -43,7 +44,7 @@ class Skeletonize3d:
         """
         pass
 
-    def peakmem_skeletonize_3d(self):
+    def peakmem_skeletonize(self):
         self.skeletonize(self.image)
 
 
@@ -218,7 +219,7 @@ class GrayReconstruction:
 
         References
         ----------
-        .. [1]: https://asv.readthedocs.io/en/stable/writing_benchmarks.html#peak-memory  # noqa
+        .. [1]: https://asv.readthedocs.io/en/stable/writing_benchmarks.html#peak-memory
         """
         pass
 
@@ -250,3 +251,39 @@ class LocalMaxima:
         morphology.local_maxima(
             self.image, connectivity=connectivity, allow_borders=allow_borders
         )
+
+
+class RemoveObjectsByDistance:
+    param_names = ["min_distance"]
+    params = [5, 100]
+
+    def setup(self, *args):
+        image = data.hubble_deep_field()
+        image = color.rgb2gray(image)
+        objects = image > 0.18  # Chosen with threshold_li
+        self.labels, _ = scipy.ndimage.label(objects)
+
+    def time_remove_near_objects(self, min_distance):
+        morphology.remove_objects_by_distance(self.labels, min_distance=min_distance)
+
+    def peakmem_reference(self, *args):
+        """Provide reference for memory measurement with empty benchmark.
+
+        Peakmem benchmarks measure the maximum amount of RAM used by a
+        function. However, this maximum also includes the memory used
+        during the setup routine (as of asv 0.2.1; see [1]_).
+        Measuring an empty peakmem function might allow us to disambiguate
+        between the memory used by setup and the memory used by target (see
+        other ``peakmem_`` functions below).
+
+        References
+        ----------
+        .. [1]: https://asv.readthedocs.io/en/stable/writing_benchmarks.html#peak-memory
+        """
+        pass
+
+    def peakmem_remove_near_objects(self, min_distance):
+        morphology.remove_objects_by_distance(
+            self.labels,
+            min_distance=min_distance,
+        )
