@@ -94,9 +94,12 @@ ax[0].set_axis_off()
 
 angle_step = 0.5 * np.diff(theta).mean()
 d_step = 0.5 * np.diff(d).mean()
-bounds = [np.rad2deg(theta[0] - angle_step),
-          np.rad2deg(theta[-1] + angle_step),
-          d[-1] + d_step, d[0] - d_step]
+bounds = [
+    np.rad2deg(theta[0] - angle_step),
+    np.rad2deg(theta[-1] + angle_step),
+    d[-1] + d_step,
+    d[0] - d_step,
+]
 ax[1].imshow(np.log(1 + h), extent=bounds, cmap=cm.gray, aspect=1 / 1.5)
 ax[1].set_title('Hough transform')
 ax[1].set_xlabel('Angles (degrees)')
@@ -110,7 +113,7 @@ ax[2].set_title('Detected lines')
 
 for _, angle, dist in zip(*hough_line_peaks(h, theta, d)):
     (x0, y0) = dist * np.array([np.cos(angle), np.sin(angle)])
-    ax[2].axline((x0, y0), slope=np.tan(angle + np.pi/2))
+    ax[2].axline((x0, y0), slope=np.tan(angle + np.pi / 2))
 
 plt.tight_layout()
 plt.show()
@@ -125,8 +128,7 @@ from skimage.transform import probabilistic_hough_line
 # Line finding using the Probabilistic Hough Transform
 image = data.camera()
 edges = canny(image, 2, 1, 25)
-lines = probabilistic_hough_line(edges, threshold=10, line_length=5,
-                                 line_gap=3)
+lines = probabilistic_hough_line(edges, threshold=10, line_length=5, line_gap=3)
 
 # Generating figure 2
 fig, axes = plt.subplots(1, 3, figsize=(15, 5), sharex=True, sharey=True)
