@@ -47,20 +47,19 @@ import matplotlib.pyplot as plt
 image = data.hubble_deep_field()[0:500, 0:500]
 image_gray = rgb2gray(image)
 
-blobs_log = blob_log(image_gray, max_sigma=30, num_sigma=10, threshold=.1)
+blobs_log = blob_log(image_gray, max_sigma=30, num_sigma=10, threshold=0.1)
 
 # Compute radii in the 3rd column.
 blobs_log[:, 2] = blobs_log[:, 2] * sqrt(2)
 
-blobs_dog = blob_dog(image_gray, max_sigma=30, threshold=.1)
+blobs_dog = blob_dog(image_gray, max_sigma=30, threshold=0.1)
 blobs_dog[:, 2] = blobs_dog[:, 2] * sqrt(2)
 
-blobs_doh = blob_doh(image_gray, max_sigma=30, threshold=.01)
+blobs_doh = blob_doh(image_gray, max_sigma=30, threshold=0.01)
 
 blobs_list = [blobs_log, blobs_dog, blobs_doh]
 colors = ['yellow', 'lime', 'red']
-titles = ['Laplacian of Gaussian', 'Difference of Gaussian',
-          'Determinant of Hessian']
+titles = ['Laplacian of Gaussian', 'Difference of Gaussian', 'Determinant of Hessian']
 sequence = zip(blobs_list, colors, titles)
 
 fig, axes = plt.subplots(1, 3, figsize=(9, 3), sharex=True, sharey=True)
