@@ -23,16 +23,20 @@ from skimage.morphology import closing
 from skimage.morphology import square
 
 datasets = {
-    'retina': {'image': data.microaneurysms(),
-               'figsize': (15, 9),
-               'diameter': 10,
-               'vis_factor': 3,
-               'title': 'Detection of microaneurysm'},
-    'page': {'image': data.page(),
-             'figsize': (15, 7),
-             'diameter': 23,
-             'vis_factor': 1,
-             'title': 'Text detection'}
+    'retina': {
+        'image': data.microaneurysms(),
+        'figsize': (15, 9),
+        'diameter': 10,
+        'vis_factor': 3,
+        'title': 'Detection of microaneurysm',
+    },
+    'page': {
+        'image': data.page(),
+        'figsize': (15, 7),
+        'diameter': 23,
+        'vis_factor': 1,
+        'title': 'Text detection',
+    },
 }
 
 for dataset in datasets.values():
@@ -43,13 +47,11 @@ for dataset in datasets.values():
 
     fig, ax = plt.subplots(2, 3, figsize=figsize)
     # Original image
-    ax[0, 0].imshow(image, cmap='gray', aspect='equal',
-                    vmin=0, vmax=255)
+    ax[0, 0].imshow(image, cmap='gray', aspect='equal', vmin=0, vmax=255)
     ax[0, 0].set_title('Original', fontsize=16)
     ax[0, 0].axis('off')
 
-    ax[1, 0].imshow(image, cmap='gray', aspect='equal',
-                    vmin=0, vmax=255)
+    ax[1, 0].imshow(image, cmap='gray', aspect='equal', vmin=0, vmax=255)
     ax[1, 0].set_title('Original', fontsize=16)
     ax[1, 0].axis('off')
 
@@ -61,13 +63,17 @@ for dataset in datasets.values():
     # We then calculate the difference to the original image.
     tophat_attr = closed_attr - image
 
-    ax[0, 1].imshow(closed_attr, cmap='gray', aspect='equal',
-                    vmin=0, vmax=255)
+    ax[0, 1].imshow(closed_attr, cmap='gray', aspect='equal', vmin=0, vmax=255)
     ax[0, 1].set_title('Diameter Closing', fontsize=16)
     ax[0, 1].axis('off')
 
-    ax[0, 2].imshow(dataset['vis_factor'] * tophat_attr, cmap='gray',
-                    aspect='equal', vmin=0, vmax=255)
+    ax[0, 2].imshow(
+        dataset['vis_factor'] * tophat_attr,
+        cmap='gray',
+        aspect='equal',
+        vmin=0,
+        vmax=255,
+    )
     ax[0, 2].set_title('Tophat (Difference)', fontsize=16)
     ax[0, 2].axis('off')
 
@@ -78,13 +84,13 @@ for dataset in datasets.values():
     # Again we calculate the difference to the original image.
     tophat = closed - image
 
-    ax[1, 1].imshow(closed, cmap='gray', aspect='equal',
-                    vmin=0, vmax=255)
+    ax[1, 1].imshow(closed, cmap='gray', aspect='equal', vmin=0, vmax=255)
     ax[1, 1].set_title('Morphological Closing', fontsize=16)
     ax[1, 1].axis('off')
 
-    ax[1, 2].imshow(dataset['vis_factor'] * tophat, cmap='gray',
-                    aspect='equal', vmin=0, vmax=255)
+    ax[1, 2].imshow(
+        dataset['vis_factor'] * tophat, cmap='gray', aspect='equal', vmin=0, vmax=255
+    )
     ax[1, 2].set_title('Tophat (Difference)', fontsize=16)
     ax[1, 2].axis('off')
     fig.suptitle(dataset['title'], fontsize=18)
