@@ -38,10 +38,15 @@ noise.
 .. _`YCbCr color space`: https://en.wikipedia.org/wiki/YCbCr
 
 """
+
 import matplotlib.pyplot as plt
 
-from skimage.restoration import (denoise_tv_chambolle, denoise_bilateral,
-                                 denoise_wavelet, estimate_sigma)
+from skimage.restoration import (
+    denoise_tv_chambolle,
+    denoise_bilateral,
+    denoise_wavelet,
+    estimate_sigma,
+)
 from skimage import data, img_as_float
 from skimage.util import random_noise
 
@@ -51,8 +56,7 @@ original = img_as_float(data.chelsea()[100:250, 50:300])
 sigma = 0.155
 noisy = random_noise(original, var=sigma**2)
 
-fig, ax = plt.subplots(nrows=2, ncols=4, figsize=(8, 5),
-                       sharex=True, sharey=True)
+fig, ax = plt.subplots(nrows=2, ncols=4, figsize=(8, 5), sharex=True, sharey=True)
 
 plt.gray()
 
@@ -68,8 +72,9 @@ ax[0, 0].set_title('Noisy')
 ax[0, 1].imshow(denoise_tv_chambolle(noisy, weight=0.1, channel_axis=-1))
 ax[0, 1].axis('off')
 ax[0, 1].set_title('TV')
-ax[0, 2].imshow(denoise_bilateral(noisy, sigma_color=0.05, sigma_spatial=15,
-                channel_axis=-1))
+ax[0, 2].imshow(
+    denoise_bilateral(noisy, sigma_color=0.05, sigma_spatial=15, channel_axis=-1)
+)
 ax[0, 2].axis('off')
 ax[0, 2].set_title('Bilateral')
 ax[0, 3].imshow(denoise_wavelet(noisy, channel_axis=-1, rescale_sigma=True))
@@ -79,12 +84,14 @@ ax[0, 3].set_title('Wavelet denoising')
 ax[1, 1].imshow(denoise_tv_chambolle(noisy, weight=0.2, channel_axis=-1))
 ax[1, 1].axis('off')
 ax[1, 1].set_title('(more) TV')
-ax[1, 2].imshow(denoise_bilateral(noisy, sigma_color=0.1, sigma_spatial=15,
-                channel_axis=-1))
+ax[1, 2].imshow(
+    denoise_bilateral(noisy, sigma_color=0.1, sigma_spatial=15, channel_axis=-1)
+)
 ax[1, 2].axis('off')
 ax[1, 2].set_title('(more) Bilateral')
-ax[1, 3].imshow(denoise_wavelet(noisy, channel_axis=-1, convert2ycbcr=True,
-                                rescale_sigma=True))
+ax[1, 3].imshow(
+    denoise_wavelet(noisy, channel_axis=-1, convert2ycbcr=True, rescale_sigma=True)
+)
 ax[1, 3].axis('off')
 ax[1, 3].set_title('Wavelet denoising\nin YCbCr colorspace')
 ax[1, 0].imshow(original)
