@@ -15,6 +15,7 @@ results in a gray level image while misregistred pixels appear colored
 in the constructed RGB image.
 
 """
+
 import numpy as np
 from matplotlib import pyplot as plt
 from skimage.color import rgb2gray
@@ -36,11 +37,9 @@ v, u = optical_flow_tvl1(image0, image1)
 
 nr, nc = image0.shape
 
-row_coords, col_coords = np.meshgrid(np.arange(nr), np.arange(nc),
-                                     indexing='ij')
+row_coords, col_coords = np.meshgrid(np.arange(nr), np.arange(nc), indexing='ij')
 
-image1_warp = warp(image1, np.array([row_coords + v, col_coords + u]),
-                   mode='edge')
+image1_warp = warp(image1, np.array([row_coords + v, col_coords + u]), mode='edge')
 
 # build an RGB image with the unregistered sequence
 seq_im = np.zeros((nr, nc, 3))
@@ -93,7 +92,7 @@ image0, image1 = vortex()
 v, u = optical_flow_ilk(image0, image1, radius=15)
 
 # --- Compute flow magnitude
-norm = np.sqrt(u ** 2 + v ** 2)
+norm = np.sqrt(u**2 + v**2)
 
 # --- Display
 fig, (ax0, ax1) = plt.subplots(1, 2, figsize=(8, 4))
@@ -108,15 +107,14 @@ ax0.set_axis_off()
 
 nvec = 20  # Number of vectors to be displayed along each image dimension
 nl, nc = image0.shape
-step = max(nl//nvec, nc//nvec)
+step = max(nl // nvec, nc // nvec)
 
 y, x = np.mgrid[:nl:step, :nc:step]
 u_ = u[::step, ::step]
 v_ = v[::step, ::step]
 
 ax1.imshow(norm)
-ax1.quiver(x, y, u_, v_, color='r', units='dots',
-           angles='xy', scale_units='xy', lw=3)
+ax1.quiver(x, y, u_, v_, color='r', units='dots', angles='xy', scale_units='xy', lw=3)
 ax1.set_title("Optical flow magnitude and vector field")
 ax1.set_axis_off()
 fig.tight_layout()
