@@ -58,7 +58,6 @@ provided by the projections), and we follow that rule here. Below is the
 original image and its Radon transform, often known as its *sinogram*:
 """
 
-
 import numpy as np
 import matplotlib.pyplot as plt
 
@@ -73,15 +72,18 @@ fig, (ax1, ax2) = plt.subplots(1, 2, figsize=(8, 4.5))
 ax1.set_title("Original")
 ax1.imshow(image, cmap=plt.cm.Greys_r)
 
-theta = np.linspace(0., 180., max(image.shape), endpoint=False)
+theta = np.linspace(0.0, 180.0, max(image.shape), endpoint=False)
 sinogram = radon(image, theta=theta)
 dx, dy = 0.5 * 180.0 / max(image.shape), 0.5 / sinogram.shape[0]
 ax2.set_title("Radon transform\n(Sinogram)")
 ax2.set_xlabel("Projection angle (deg)")
 ax2.set_ylabel("Projection position (pixels)")
-ax2.imshow(sinogram, cmap=plt.cm.Greys_r,
-           extent=(-dx, 180.0 + dx, -dy, sinogram.shape[0] + dy),
-           aspect='auto')
+ax2.imshow(
+    sinogram,
+    cmap=plt.cm.Greys_r,
+    extent=(-dx, 180.0 + dx, -dy, sinogram.shape[0] + dy),
+    aspect='auto',
+)
 
 fig.tight_layout()
 plt.show()
@@ -125,8 +127,7 @@ error = reconstruction_fbp - image
 print(f'FBP rms reconstruction error: {np.sqrt(np.mean(error**2)):.3g}')
 
 imkwargs = dict(vmin=-0.2, vmax=0.2)
-fig, (ax1, ax2) = plt.subplots(1, 2, figsize=(8, 4.5),
-                               sharex=True, sharey=True)
+fig, (ax1, ax2) = plt.subplots(1, 2, figsize=(8, 4.5), sharex=True, sharey=True)
 ax1.set_title("Reconstruction\nFiltered back projection")
 ax1.imshow(reconstruction_fbp, cmap=plt.cm.Greys_r)
 ax2.set_title("Reconstruction error\nFiltered back projection")
@@ -171,8 +172,9 @@ from skimage.transform import iradon_sart
 
 reconstruction_sart = iradon_sart(sinogram, theta=theta)
 error = reconstruction_sart - image
-print(f'SART (1 iteration) rms reconstruction error: '
-      f'{np.sqrt(np.mean(error**2)):.3g}')
+print(
+    f'SART (1 iteration) rms reconstruction error: ' f'{np.sqrt(np.mean(error**2)):.3g}'
+)
 
 fig, axes = plt.subplots(2, 2, figsize=(8, 8.5), sharex=True, sharey=True)
 ax = axes.ravel()
@@ -185,11 +187,12 @@ ax[1].imshow(reconstruction_sart - image, cmap=plt.cm.Greys_r, **imkwargs)
 
 # Run a second iteration of SART by supplying the reconstruction
 # from the first iteration as an initial estimate
-reconstruction_sart2 = iradon_sart(sinogram, theta=theta,
-                                   image=reconstruction_sart)
+reconstruction_sart2 = iradon_sart(sinogram, theta=theta, image=reconstruction_sart)
 error = reconstruction_sart2 - image
-print(f'SART (2 iterations) rms reconstruction error: '
-      f'{np.sqrt(np.mean(error**2)):.3g}')
+print(
+    f'SART (2 iterations) rms reconstruction error: '
+    f'{np.sqrt(np.mean(error**2)):.3g}'
+)
 
 ax[2].set_title("Reconstruction\nSART, 2 iterations")
 ax[2].imshow(reconstruction_sart2, cmap=plt.cm.Greys_r)
