@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-"""Script to auto-generate our API docs.
-"""
+"""Script to auto-generate our API docs."""
 
 import sys
 
@@ -43,7 +42,7 @@ if __name__ == '__main__':
     source_lines = open('../skimage/__init__.py').readlines()
     version = 'vUndefined'
     for l in source_lines:
-        if l.startswith('__version__'):
+        if l.startswith('__version__ = '):
             source_version = _version.parse(l.split("'")[1])
             break
 
@@ -59,4 +58,12 @@ if __name__ == '__main__':
     ]
     docwriter.write_api_docs(outdir)
     docwriter.write_index(outdir, 'api', relative_to='source/api')
-    print(f'{len(docwriter.written_modules)} files written')
+
+    if len(docwriter.written_modules) <= 1:
+        msg = (
+            f"expected more modules, only wrote files for: "
+            f"{docwriter.written_modules!r}"
+        )
+        raise RuntimeWarning(msg)
+    else:
+        print(f'{len(docwriter.written_modules)} files written')
