@@ -1,5 +1,4 @@
 import pytest
-from skimage._shared.testing import setup_test, teardown_test
 
 # List of files that pytest should ignore
 collect_ignore = [
@@ -7,13 +6,6 @@ collect_ignore = [
 ]
 
 
-def pytest_runtest_setup(item):
-    setup_test()
-
-
-def pytest_runtest_teardown(item):
-    teardown_test()
-
 @pytest.fixture(autouse=True)
 def handle_np2():
     # TODO: remove when we require numpy >= 2
