@@ -2,13 +2,20 @@ import numpy as np
 
 from .._shared._geometry import polygon_clip
 from .._shared.version_requirements import require
-from ._draw import (_coords_inside_image, _line, _line_aa,
-                    _polygon, _ellipse_perimeter,
-                    _circle_perimeter, _circle_perimeter_aa,
-                    _bezier_curve)
+from .._shared.compat import NP_COPY_IF_NEEDED
+from ._draw import (
+    _coords_inside_image,
+    _line,
+    _line_aa,
+    _polygon,
+    _ellipse_perimeter,
+    _circle_perimeter,
+    _circle_perimeter_aa,
+    _bezier_curve,
+)
 
 
-def _ellipse_in_shape(shape, center, radii, rotation=0.):
+def _ellipse_in_shape(shape, center, radii, rotation=0.0):
     """Generate coordinates of points within ellipse bounded by shape.
 
     Parameters
@@ -32,18 +39,19 @@ def _ellipse_in_shape(shape, center, radii, rotation=0.):
     cols : iterable of ints
         Corresponding column coordinates representing values within the ellipse.
     """
-    r_lim, c_lim = np.ogrid[0:float(shape[0]), 0:float(shape[1])]
+    r_lim, c_lim = np.ogrid[0 : float(shape[0]), 0 : float(shape[1])]
     r_org, c_org = center
     r_rad, c_rad = radii
     rotation %= np.pi
     sin_alpha, cos_alpha = np.sin(rotation), np.cos(rotation)
     r, c = (r_lim - r_org), (c_lim - c_org)
-    distances = ((r * cos_alpha + c * sin_alpha) / r_rad) ** 2 \
-                + ((r * sin_alpha - c * cos_alpha) / c_rad) ** 2
+    distances = ((r * cos_alpha + c * sin_alpha) / r_rad) ** 2 + (
+        (r * sin_alpha - c * cos_alpha) / c_rad
+    ) ** 2
     return np.nonzero(distances < 1)
 
 
-def ellipse(r, c, r_radius, c_radius, shape=None, rotation=0.):
+def ellipse(r, c, r_radius, c_radius, shape=None, rotation=0.0):
     """Generate coordinates of pixels within ellipse.
 
     Parameters
@@ -117,10 +125,8 @@ def ellipse(r, c, r_radius, c_radius, shape=None, rotation=0.):
     rotation %= np.pi
 
     # compute rotated radii by given rotation
-    r_radius_rot = abs(r_radius * np.cos(rotation)) \
-                   + c_radius * np.sin(rotation)
-    c_radius_rot = r_radius * np.sin(rotation) \
-                   + abs(c_radius * np.cos(rotation))
+    r_radius_rot = abs(r_radius * np.cos(rotation)) + c_radius * np.sin(rotation)
+    c_radius_rot = r_radius * np.sin(rotation) + abs(c_radius * np.cos(rotation))
     # The upper_left and lower_right corners of the smallest rectangle
     # containing the ellipse.
     radii_rot = np.array([r_radius_rot, c_radius_rot])
@@ -237,6 +243,9 @@ def polygon_perimeter(r, c, shape=None, clip=False):
 
     Examples
     --------
+    .. testsetup::
+        >>> import pytest; _ = pytest.importorskip('matplotlib')
+
     >>> from skimage.draw import polygon_perimeter
     >>> img = np.zeros((10, 10), dtype=np.uint8)
     >>> rr, cc = polygon_perimeter([5, -1, 5, 10],
@@ -261,8 +270,7 @@ def polygon_perimeter(r, c, shape=None, clip=False):
             raise ValueError("Must specify clipping shape")
         clip_box = np.array([0, 0, shape[0] - 1, shape[1] - 1])
     else:
-        clip_box = np.array([np.min(r), np.min(c),
-                             np.max(r), np.max(c)])
+        clip_box = np.array([np.min(r), np.min(c), np.max(r), np.max(c)])
 
     # Do the clipping irrespective of whether clip is set.  This
     # ensures that the returned polygon is closed and is an array.
@@ -295,13 +303,13 @@ def set_color(image, coords, color, alpha=1):
 
     Parameters
     ----------
-    image : (M, N, D) ndarray
+    image : (M, N, C) ndarray
         Image
-    coords : tuple of ((P,) ndarray, (P,) ndarray)
+    coords : tuple of ((K,) ndarray, (K,) ndarray)
         Row and column coordinates of pixels to be colored.
-    color : (D,) ndarray
+    color : (C,) ndarray
         Color to be assigned to coordinates in the image.
-    alpha : scalar or (N,) ndarray
+    alpha : scalar or (K,) ndarray
         Alpha values used to blend color with image.  0 is transparent,
         1 is opaque.
 
@@ -329,11 +337,13 @@ def set_color(image, coords, color, alpha=1):
     if image.ndim == 2:
         image = image[..., np.newaxis]
 
-    color = np.array(color, ndmin=1, copy=False)
+    color = np.array(color, ndmin=1, copy=NP_COPY_IF_NEEDED)
 
     if image.shape[-1] != color.shape[-1]:
-        raise ValueError(f'Color shape ({color.shape[0]}) must match last '
-                          'image dimension ({image.shape[-1]}).')
+        raise ValueError(
+            f'Color shape ({color.shape[0]}) must match last '
+            'image dimension ({image.shape[-1]}).'
+        )
 
     if np.isscalar(alpha):
         # Can be replaced by ``full_like`` when numpy 1.8 becomes
@@ -855,8 +865,7 @@ def rectangle(start, end=None, extent=None, shape=None):
         n_dim = len(start)
         br = np.minimum(shape[0:n_dim], br)
         tl = np.maximum(np.zeros_like(shape[0:n_dim]), tl)
-    coords = np.meshgrid(*[np.arange(st, en) for st, en in zip(tuple(tl),
-                                                               tuple(br))])
+    coords = np.meshgrid(*[np.arange(st, en) for st, en in zip(tuple(tl), tuple(br))])
     return coords
 
 
@@ -897,6 +906,9 @@ def rectangle_perimeter(start, end=None, extent=None, shape=None, clip=False):
 
     Examples
     --------
+    .. testsetup::
+        >>> import pytest; _ = pytest.importorskip('matplotlib')
+
     >>> import numpy as np
     >>> from skimage.draw import rectangle_perimeter
     >>> img = np.zeros((5, 6), dtype=np.uint8)
@@ -922,15 +934,11 @@ def rectangle_perimeter(start, end=None, extent=None, shape=None, clip=False):
            [0, 0, 1, 1, 1]], dtype=uint8)
 
     """
-    top_left, bottom_right = _rectangle_slice(start=start,
-                                              end=end,
-                                              extent=extent)
+    top_left, bottom_right = _rectangle_slice(start=start, end=end, extent=extent)
 
     top_left -= 1
-    r = [top_left[0], top_left[0], bottom_right[0], bottom_right[0],
-         top_left[0]]
-    c = [top_left[1], bottom_right[1], bottom_right[1], top_left[1],
-         top_left[1]]
+    r = [top_left[0], top_left[0], bottom_right[0], bottom_right[0], top_left[0]]
+    c = [top_left[1], bottom_right[1], bottom_right[1], top_left[1], top_left[1]]
     return polygon_perimeter(r, c, shape=shape, clip=clip)
 
 
@@ -938,8 +946,8 @@ def _rectangle_slice(start, end=None, extent=None):
     """Return the slice ``(top_left, bottom_right)`` of the rectangle.
 
     Returns
-    =======
-    (top_left, bottomm_right)
+    -------
+    (top_left, bottom_right)
         The slice you would need to select the region in the rectangle defined
         by the parameters.
         Select it like:
