@@ -1,34 +1,34 @@
 """
 Grayscale morphological operations
 """
-import functools
+
+import warnings
 
 import numpy as np
 from scipy import ndimage as ndi
 
-from ..util import crop
-from .footprints import _footprint_is_sequence, _shape_from_sequence
+from .footprints import _footprint_is_sequence, mirror_footprint, pad_footprint
 from .misc import default_footprint
-
-__all__ = ['erosion', 'dilation', 'opening', 'closing', 'white_tophat',
-           'black_tophat']
+from .._shared.utils import DEPRECATED
 
 
-def _iterate_gray_func(gray_func, image, footprints, out):
-    """Helper to call `binary_func` for each footprint in a sequence.
+__all__ = ['erosion', 'dilation', 'opening', 'closing', 'white_tophat', 'black_tophat']
 
-    binary_func is a binary morphology function that accepts "structure",
-    "output" and "iterations" keyword arguments
-    (e.g. `scipy.ndimage.binary_erosion`).
+
+def _iterate_gray_func(gray_func, image, footprints, out, mode, cval):
+    """Helper to call `gray_func` for each footprint in a sequence.
+
+    `gray_func` is a morphology function that accepts `footprint`, `output`,
+    `mode` and `cval` keyword arguments (e.g. `scipy.ndimage.grey_erosion`).
     """
     fp, num_iter = footprints[0]
-    gray_func(image, footprint=fp, output=out)
+    gray_func(image, footprint=fp, output=out, mode=mode, cval=cval)
     for _ in range(1, num_iter):
-        gray_func(out.copy(), footprint=fp, output=out)
+        gray_func(out.copy(), footprint=fp, output=out, mode=mode, cval=cval)
     for fp, num_iter in footprints[1:]:
         # Note: out.copy() because the computation cannot be in-place!
         for _ in range(num_iter):
-            gray_func(out.copy(), footprint=fp, output=out)
+            gray_func(out.copy(), footprint=fp, output=out, mode=mode, cval=cval)
     return out
 
 
@@ -42,14 +42,16 @@ def _shift_footprint(footprint, shift_x, shift_y):
     ----------
     footprint : 2D array, shape (M, N)
         The input footprint.
-    shift_x, shift_y : bool
-        Whether to move `footprint` along each axis.
+    shift_x, shift_y : bool or None
+        Whether to move `footprint` along each axis. If ``None``, the
+        array is not modified along that dimension.
 
     Returns
     -------
     out : 2D array, shape (M + int(shift_x), N + int(shift_y))
         The shifted footprint.
     """
+    footprint = np.asarray(footprint)
     if footprint.ndim != 2:
         # do nothing for 1D or 3D or higher footprints
         return footprint
@@ -70,93 +72,70 @@ def _shift_footprint(footprint, shift_x, shift_y):
     return footprint
 
 
-def _invert_footprint(footprint):
-    """Change the order of the values in `footprint`.
+def _shift_footprints(footprint, shift_x, shift_y):
+    """Shifts the footprints, whether it's a single array or a sequence.
 
-    This is a patch for the *weird* footprint inversion in
-    `ndi.grey_morphology` [1]_.
-
-    Parameters
-    ----------
-    footprint : array
-        The input footprint.
-
-    Returns
-    -------
-    inverted : array, same shape and type as `footprint`
-        The footprint, in opposite order.
-
-    Examples
-    --------
-    >>> footprint = np.array([[0, 0, 0], [0, 1, 1], [0, 1, 1]], np.uint8)
-    >>> _invert_footprint(footprint)
-    array([[1, 1, 0],
-           [1, 1, 0],
-           [0, 0, 0]], dtype=uint8)
-
-    References
-    ----------
-    .. [1] https://github.com/scipy/scipy/blob/ec20ababa400e39ac3ffc9148c01ef86d5349332/scipy/ndimage/morphology.py#L1285  # noqa
+    See `_shift_footprint`, which is called for each array in the sequence.
     """
-    inverted = footprint[(slice(None, None, -1),) * footprint.ndim]
-    return inverted
+    if shift_x is DEPRECATED and shift_y is DEPRECATED:
+        return footprint
+
+    warning_msg = (
+        "The parameters `shift_x` and `shift_y` are deprecated since v0.23 and "
+        "will be removed in v0.26. Use `pad_footprint` or modify the footprint"
+        "manually instead."
+    )
+    warnings.warn(warning_msg, FutureWarning, stacklevel=4)
+
+    if _footprint_is_sequence(footprint):
+        return tuple((_shift_footprint(fp, shift_x, shift_y), n) for fp, n in footprint)
+    return _shift_footprint(footprint, shift_x, shift_y)
 
 
-def pad_for_eccentric_footprints(func):
-    """Pad input images for certain morphological operations.
-
-    Parameters
-    ----------
-    func : callable
-        A morphological function, either opening or closing, that
-        supports eccentric footprints. Its parameters must
-        include at least `image`, `footprint`, and `out`.
-
-    Returns
-    -------
-    func_out : callable
-        The same function, but correctly padding the input image before
-        applying the input function.
-
-    See Also
-    --------
-    opening, closing.
-    """
-    @functools.wraps(func)
-    def func_out(image, footprint, out=None, *args, **kwargs):
-        pad_widths = []
-        padding = False
-        if out is None:
-            out = np.empty_like(image)
-        if _footprint_is_sequence(footprint):
-            # Note: in practice none of our built-in footprint sequences will
-            #       require padding (all are symmetric and have odd sizes)
-            footprint_shape = _shape_from_sequence(footprint)
+def _min_max_to_constant_mode(dtype, mode, cval):
+    """Replace 'max' and 'min' with appropriate 'cval' and 'constant' mode."""
+    if mode == "max":
+        mode = "constant"
+        if np.issubdtype(dtype, bool):
+            cval = True
+        elif np.issubdtype(dtype, np.integer):
+            cval = np.iinfo(dtype).max
         else:
-            footprint_shape = footprint.shape
-        for axis_len in footprint_shape:
-            if axis_len % 2 == 0:
-                axis_pad_width = axis_len - 1
-                padding = True
-            else:
-                axis_pad_width = 0
-            pad_widths.append((axis_pad_width,) * 2)
-        if padding:
-            image = np.pad(image, pad_widths, mode='edge')
-            out_temp = np.empty_like(image)
+            cval = np.inf
+    elif mode == "min":
+        mode = "constant"
+        if np.issubdtype(dtype, bool):
+            cval = False
+        elif np.issubdtype(dtype, np.integer):
+            cval = np.iinfo(dtype).min
         else:
-            out_temp = out
-        out_temp = func(image, footprint, out=out_temp, *args, **kwargs)
-        if padding:
-            out[:] = crop(out_temp, pad_widths)
-        else:
-            out = out_temp
-        return out
-    return func_out
+            cval = -np.inf
+    return mode, cval
+
+
+_SUPPORTED_MODES = {
+    "reflect",
+    "constant",
+    "nearest",
+    "mirror",
+    "wrap",
+    "max",
+    "min",
+    "ignore",
+}
 
 
 @default_footprint
-def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
+def erosion(
+    image,
+    footprint=None,
+    out=None,
+    shift_x=DEPRECATED,
+    shift_y=DEPRECATED,
+    *,
+    mode="reflect",
+    cval=0.0,
+):
     """Return grayscale morphological erosion of an image.
 
     Morphological erosion sets a pixel at (i,j) to the minimum over all pixels
@@ -175,20 +154,35 @@ def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
     out : ndarrays, optional
         The array to store the result of the morphology. If None is
         passed, a new array will be allocated.
-    shift_x, shift_y : bool, optional
-        shift footprint about center point. This only affects
-        eccentric footprints (i.e. footprint with even numbered
-        sides).
+    mode : str, optional
+        The `mode` parameter determines how the array borders are handled.
+        Valid modes are: 'reflect', 'constant', 'nearest', 'mirror', 'wrap',
+        'max', 'min', or 'ignore'.
+        If 'max' or 'ignore', pixels outside the image domain are assumed
+        to be the maximum for the image's dtype, which causes them to not
+        influence the result. Default is 'reflect'.
+    cval : scalar, optional
+        Value to fill past edges of input if `mode` is 'constant'. Default
+        is 0.0.
+
+        .. versionadded:: 0.23
+            `mode` and `cval` were added in 0.23.
 
     Returns
     -------
     eroded : array, same shape as `image`
         The result of the morphological erosion.
 
+    Other Parameters
+    ----------------
+    shift_x, shift_y : DEPRECATED
+
+        .. deprecated:: 0.23
+
     Notes
     -----
     For ``uint8`` (and ``uint16`` up to a certain bit-depth) data, the
-    lower algorithm complexity makes the `skimage.filters.rank.minimum`
+    lower algorithm complexity makes the :func:`skimage.filters.rank.minimum`
     function more efficient for larger images and footprints.
 
     The footprint can also be a provided as a sequence of 2-tuples where the
@@ -198,20 +192,24 @@ def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
     would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
     effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
     computational cost. Most of the builtin footprints such as
-    ``skimage.morphology.disk`` provide an option to automatically generate a
-    footprint sequence of this type.
+    :func:`skimage.morphology.disk` provide an option to automatically generate
+    a footprint sequence of this type.
+
+    For even-sized footprints, :func:`skimage.morphology.binary_erosion` and
+    this function produce an output that differs: one is shifted by one pixel
+    compared to the other.
 
     Examples
     --------
     >>> # Erosion shrinks bright regions
     >>> import numpy as np
-    >>> from skimage.morphology import square
+    >>> from skimage.morphology import footprint_rectangle
     >>> bright_square = np.array([[0, 0, 0, 0, 0],
     ...                           [0, 1, 1, 1, 0],
     ...                           [0, 1, 1, 1, 0],
     ...                           [0, 1, 1, 1, 0],
     ...                           [0, 0, 0, 0, 0]], dtype=np.uint8)
-    >>> erosion(bright_square, square(3))
+    >>> erosion(bright_square, footprint_rectangle((3, 3)))
     array([[0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0],
@@ -222,19 +220,39 @@ def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
     if out is None:
         out = np.empty_like(image)
 
-    if _footprint_is_sequence(footprint):
-        footprints = tuple((_shift_footprint(fp, shift_x, shift_y), n)
-                           for fp, n in footprint)
-        return _iterate_gray_func(ndi.grey_erosion, image, footprints, out)
+    if mode not in _SUPPORTED_MODES:
+        raise ValueError(f"unsupported mode, got {mode!r}")
+    if mode == "ignore":
+        mode = "max"
+    mode, cval = _min_max_to_constant_mode(image.dtype, mode, cval)
 
-    footprint = np.array(footprint)
-    footprint = _shift_footprint(footprint, shift_x, shift_y)
-    ndi.grey_erosion(image, footprint=footprint, output=out)
+    footprint = _shift_footprints(footprint, shift_x, shift_y)
+    footprint = pad_footprint(footprint, pad_end=False)
+    if not _footprint_is_sequence(footprint):
+        footprint = [(footprint, 1)]
+
+    out = _iterate_gray_func(
+        gray_func=ndi.grey_erosion,
+        image=image,
+        footprints=footprint,
+        out=out,
+        mode=mode,
+        cval=cval,
+    )
     return out
 
 
 @default_footprint
-def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
+def dilation(
+    image,
+    footprint=None,
+    out=None,
+    shift_x=DEPRECATED,
+    shift_y=DEPRECATED,
+    *,
+    mode="reflect",
+    cval=0.0,
+):
     """Return grayscale morphological dilation of an image.
 
     Morphological dilation sets the value of a pixel to the maximum over all
@@ -254,21 +272,36 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     out : ndarray, optional
         The array to store the result of the morphology. If None is
         passed, a new array will be allocated.
-    shift_x, shift_y : bool, optional
-        Shift footprint about center point. This only affects 2D
-        eccentric footprints (i.e., footprints with even-numbered
-        sides).
+    mode : str, optional
+        The `mode` parameter determines how the array borders are handled.
+        Valid modes are: 'reflect', 'constant', 'nearest', 'mirror', 'wrap',
+        'max', 'min', or 'ignore'.
+        If 'min' or 'ignore', pixels outside the image domain are assumed
+        to be the maximum for the image's dtype, which causes them to not
+        influence the result. Default is 'reflect'.
+    cval : scalar, optional
+        Value to fill past edges of input if `mode` is 'constant'. Default
+        is 0.0.
+
+        .. versionadded:: 0.23
+            `mode` and `cval` were added in 0.23.
 
     Returns
     -------
     dilated : uint8 array, same shape and type as `image`
         The result of the morphological dilation.
 
+    Other Parameters
+    ----------------
+    shift_x, shift_y : DEPRECATED
+
+        .. deprecated:: 0.23
+
     Notes
     -----
-    For `uint8` (and `uint16` up to a certain bit-depth) data, the lower
-    algorithm complexity makes the `skimage.filters.rank.maximum` function more
-    efficient for larger images and footprints.
+    For ``uint8`` (and ``uint16`` up to a certain bit-depth) data, the lower
+    algorithm complexity makes the :func:`skimage.filters.rank.maximum`
+    function more efficient for larger images and footprints.
 
     The footprint can also be a provided as a sequence of 2-tuples where the
     first element of each 2-tuple is a footprint ndarray and the second element
@@ -277,20 +310,24 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
     effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
     computational cost. Most of the builtin footprints such as
-    ``skimage.morphology.disk`` provide an option to automatically generate a
-    footprint sequence of this type.
+    :func:`skimage.morphology.disk` provide an option to automatically generate
+    a footprint sequence of this type.
+
+    For non-symmetric footprints, :func:`skimage.morphology.binary_dilation`
+    and :func:`skimage.morphology.dilation` produce an output that differs:
+    `binary_dilation` mirrors the footprint, whereas `dilation` does not.
 
     Examples
     --------
     >>> # Dilation enlarges bright regions
     >>> import numpy as np
-    >>> from skimage.morphology import square
+    >>> from skimage.morphology import footprint_rectangle
     >>> bright_pixel = np.array([[0, 0, 0, 0, 0],
     ...                          [0, 0, 0, 0, 0],
     ...                          [0, 0, 1, 0, 0],
     ...                          [0, 0, 0, 0, 0],
     ...                          [0, 0, 0, 0, 0]], dtype=np.uint8)
-    >>> dilation(bright_pixel, square(3))
+    >>> dilation(bright_pixel, footprint_rectangle((3, 3)))
     array([[0, 0, 0, 0, 0],
            [0, 1, 1, 1, 0],
            [0, 1, 1, 1, 0],
@@ -301,30 +338,33 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     if out is None:
         out = np.empty_like(image)
 
-    if _footprint_is_sequence(footprint):
-        # shift and invert (see comment below) each footprint
-        footprints = tuple(
-            (_invert_footprint(_shift_footprint(fp, shift_x, shift_y)), n)
-            for fp, n in footprint
-        )
-        return _iterate_gray_func(ndi.grey_dilation, image, footprints, out)
+    if mode not in _SUPPORTED_MODES:
+        raise ValueError(f"unsupported mode, got {mode!r}")
+    if mode == "ignore":
+        mode = "min"
+    mode, cval = _min_max_to_constant_mode(image.dtype, mode, cval)
 
-    footprint = np.array(footprint)
-    footprint = _shift_footprint(footprint, shift_x, shift_y)
-    # Inside ndi.grey_dilation, the footprint is inverted,
-    # e.g. `footprint = footprint[::-1, ::-1]` for 2D [1]_, for reasons unknown
-    # to this author (@jni). To "patch" this behaviour, we invert our own
-    # footprint before passing it to `ndi.grey_dilation`.
-    # [1] https://github.com/scipy/scipy/blob/ec20ababa400e39ac3ffc9148c01ef86d5349332/scipy/ndimage/morphology.py#L1285  # noqa
-    footprint = _invert_footprint(footprint)
+    footprint = _shift_footprints(footprint, shift_x, shift_y)
+    footprint = pad_footprint(footprint, pad_end=False)
+    # Note that `ndi.grey_dilation` mirrors the footprint and this
+    # additional inversion should be removed in skimage2, see gh-6676.
+    footprint = mirror_footprint(footprint)
+    if not _footprint_is_sequence(footprint):
+        footprint = [(footprint, 1)]
 
-    ndi.grey_dilation(image, footprint=footprint, output=out)
+    out = _iterate_gray_func(
+        gray_func=ndi.grey_dilation,
+        image=image,
+        footprints=footprint,
+        out=out,
+        mode=mode,
+        cval=cval,
+    )
     return out
 
 
 @default_footprint
-@pad_for_eccentric_footprints
-def opening(image, footprint=None, out=None):
+def opening(image, footprint=None, out=None, *, mode="reflect", cval=0.0):
     """Return grayscale morphological opening of an image.
 
     The morphological opening of an image is defined as an erosion followed by
@@ -344,6 +384,20 @@ def opening(image, footprint=None, out=None):
     out : ndarray, optional
         The array to store the result of the morphology. If None
         is passed, a new array will be allocated.
+    mode : str, optional
+        The `mode` parameter determines how the array borders are handled.
+        Valid modes are: 'reflect', 'constant', 'nearest', 'mirror', 'wrap',
+        'max', 'min', or 'ignore'.
+        If 'ignore', pixels outside the image domain are assumed
+        to be the maximum for the image's dtype in the erosion, and minimum
+        in the dilation, which causes them to not influence the result.
+        Default is 'reflect'.
+    cval : scalar, optional
+        Value to fill past edges of input if `mode` is 'constant'. Default
+        is 0.0.
+
+        .. versionadded:: 0.23
+            `mode` and `cval` were added in 0.23.
 
     Returns
     -------
@@ -359,20 +413,20 @@ def opening(image, footprint=None, out=None):
     would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
     effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
     computational cost. Most of the builtin footprints such as
-    ``skimage.morphology.disk`` provide an option to automatically generate a
-    footprint sequence of this type.
+    :func:`skimage.morphology.disk` provide an option to automatically generate
+    a footprint sequence of this type.
 
     Examples
     --------
     >>> # Open up gap between two bright regions (but also shrink regions)
     >>> import numpy as np
-    >>> from skimage.morphology import square
+    >>> from skimage.morphology import footprint_rectangle
     >>> bad_connection = np.array([[1, 0, 0, 0, 1],
     ...                            [1, 1, 0, 1, 1],
     ...                            [1, 1, 1, 1, 1],
     ...                            [1, 1, 0, 1, 1],
     ...                            [1, 0, 0, 0, 1]], dtype=np.uint8)
-    >>> opening(bad_connection, square(3))
+    >>> opening(bad_connection, footprint_rectangle((3, 3)))
     array([[0, 0, 0, 0, 0],
            [1, 1, 0, 1, 1],
            [1, 1, 0, 1, 1],
@@ -380,15 +434,14 @@ def opening(image, footprint=None, out=None):
            [0, 0, 0, 0, 0]], dtype=uint8)
 
     """
-    eroded = erosion(image, footprint)
-    # note: shift_x, shift_y do nothing if footprint side length is odd
-    out = dilation(eroded, footprint, out=out, shift_x=True, shift_y=True)
+    footprint = pad_footprint(footprint, pad_end=False)
+    eroded = erosion(image, footprint, mode=mode, cval=cval)
+    out = dilation(eroded, mirror_footprint(footprint), out=out, mode=mode, cval=cval)
     return out
 
 
 @default_footprint
-@pad_for_eccentric_footprints
-def closing(image, footprint=None, out=None):
+def closing(image, footprint=None, out=None, *, mode="reflect", cval=0.0):
     """Return grayscale morphological closing of an image.
 
     The morphological closing of an image is defined as a dilation followed by
@@ -408,6 +461,20 @@ def closing(image, footprint=None, out=None):
     out : ndarray, optional
         The array to store the result of the morphology. If None,
         a new array will be allocated.
+    mode : str, optional
+        The `mode` parameter determines how the array borders are handled.
+        Valid modes are: 'reflect', 'constant', 'nearest', 'mirror', 'wrap',
+        'max', 'min', or 'ignore'.
+        If 'ignore', pixels outside the image domain are assumed
+        to be the maximum for the image's dtype in the erosion, and minimum
+        in the dilation, which causes them to not influence the result.
+        Default is 'reflect'.
+    cval : scalar, optional
+        Value to fill past edges of input if `mode` is 'constant'. Default
+        is 0.0.
+
+        .. versionadded:: 0.23
+            `mode` and `cval` were added in 0.23.
 
     Returns
     -------
@@ -423,20 +490,20 @@ def closing(image, footprint=None, out=None):
     would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
     effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
     computational cost. Most of the builtin footprints such as
-    ``skimage.morphology.disk`` provide an option to automatically generate a
-    footprint sequence of this type.
+    :func:`skimage.morphology.disk` provide an option to automatically generate
+    a footprint sequence of this type.
 
     Examples
     --------
     >>> # Close a gap between two bright lines
     >>> import numpy as np
-    >>> from skimage.morphology import square
+    >>> from skimage.morphology import footprint_rectangle
     >>> broken_line = np.array([[0, 0, 0, 0, 0],
     ...                         [0, 0, 0, 0, 0],
     ...                         [1, 1, 0, 1, 1],
     ...                         [0, 0, 0, 0, 0],
     ...                         [0, 0, 0, 0, 0]], dtype=np.uint8)
-    >>> closing(broken_line, square(3))
+    >>> closing(broken_line, footprint_rectangle((3, 3)))
     array([[0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0],
            [1, 1, 1, 1, 1],
@@ -444,31 +511,14 @@ def closing(image, footprint=None, out=None):
            [0, 0, 0, 0, 0]], dtype=uint8)
 
     """
-    dilated = dilation(image, footprint)
-    # note: shift_x, shift_y do nothing if footprint side length is odd
-    out = erosion(dilated, footprint, out=out, shift_x=True, shift_y=True)
+    footprint = pad_footprint(footprint, pad_end=False)
+    dilated = dilation(image, footprint, mode=mode, cval=cval)
+    out = erosion(dilated, mirror_footprint(footprint), out=out, mode=mode, cval=cval)
     return out
 
 
-def _white_tophat_seqence(image, footprints, out):
-    """Return white top hat for a sequence of footprints.
-
-    Like SciPy's implementation, but with ``ndi.grey_erosion`` and
-    ``ndi.grey_dilation`` wrapped with ``_iterate_gray_func``.
-    """
-    tmp = _iterate_gray_func(ndi.grey_erosion, image, footprints, out)
-    tmp = _iterate_gray_func(ndi.grey_dilation, tmp.copy(), footprints, out)
-    if tmp is None:
-        tmp = out
-    if image.dtype == np.bool_ and tmp.dtype == np.bool_:
-        np.bitwise_xor(image, tmp, out=tmp)
-    else:
-        np.subtract(image, tmp, out=tmp)
-    return tmp
-
-
 @default_footprint
-def white_tophat(image, footprint=None, out=None):
+def white_tophat(image, footprint=None, out=None, *, mode="reflect", cval=0.0):
     """Return white top hat of an image.
 
     The white top hat of an image is defined as the image minus its
@@ -487,6 +537,17 @@ def white_tophat(image, footprint=None, out=None):
     out : ndarray, optional
         The array to store the result of the morphology. If None
         is passed, a new array will be allocated.
+    mode : str, optional
+        The `mode` parameter determines how the array borders are handled.
+        Valid modes are: 'reflect', 'constant', 'nearest', 'mirror', 'wrap',
+        'max', 'min', or 'ignore'. See :func:`skimage.morphology.opening`.
+        Default is 'reflect'.
+    cval : scalar, optional
+        Value to fill past edges of input if `mode` is 'constant'. Default
+        is 0.0.
+
+        .. versionadded:: 0.23
+            `mode` and `cval` were added in 0.23.
 
     Returns
     -------
@@ -502,8 +563,8 @@ def white_tophat(image, footprint=None, out=None):
     would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
     effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
     computational cost. Most of the builtin footprints such as
-    ``skimage.morphology.disk`` provide an option to automatically generate a
-    footprint sequence of this type.
+    :func:`skimage.morphology.disk` provide an option to automatically generate
+    a footprint sequence of this type.
 
     See Also
     --------
@@ -517,13 +578,13 @@ def white_tophat(image, footprint=None, out=None):
     --------
     >>> # Subtract gray background from bright peak
     >>> import numpy as np
-    >>> from skimage.morphology import square
+    >>> from skimage.morphology import footprint_rectangle
     >>> bright_on_gray = np.array([[2, 3, 3, 3, 2],
     ...                            [3, 4, 5, 4, 3],
     ...                            [3, 5, 9, 5, 3],
     ...                            [3, 4, 5, 4, 3],
     ...                            [2, 3, 3, 3, 2]], dtype=np.uint8)
-    >>> white_tophat(bright_on_gray, square(3))
+    >>> white_tophat(bright_on_gray, footprint_rectangle((3, 3)))
     array([[0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0],
            [0, 1, 5, 1, 0],
@@ -532,32 +593,25 @@ def white_tophat(image, footprint=None, out=None):
 
     """
     if out is image:
-        opened = opening(image, footprint)
+        # We need a temporary image
+        opened = opening(image, footprint, mode=mode, cval=cval)
         if np.issubdtype(opened.dtype, bool):
             np.logical_xor(out, opened, out=out)
         else:
             out -= opened
         return out
-    elif out is None:
-        out = np.empty_like(image)
-    # promote bool to a type that allows arithmetic operations
-    if isinstance(image, np.ndarray) and image.dtype == bool:
-        image_ = image.view(dtype=np.uint8)
+
+    # Else write intermediate result into output image
+    out = opening(image, footprint, out=out, mode=mode, cval=cval)
+    if np.issubdtype(out.dtype, bool):
+        np.logical_xor(image, out, out=out)
     else:
-        image_ = image
-    if isinstance(out, np.ndarray) and out.dtype == bool:
-        out_ = out.view(dtype=np.uint8)
-    else:
-        out_ = out
-    if _footprint_is_sequence(footprint):
-        return _white_tophat_seqence(image_, footprint, out_)
-    footprint = np.array(footprint)
-    out_ = ndi.white_tophat(image_, footprint=footprint, output=out_)
+        np.subtract(image, out, out=out)
     return out
 
 
 @default_footprint
-def black_tophat(image, footprint=None, out=None):
+def black_tophat(image, footprint=None, out=None, *, mode="reflect", cval=0.0):
     """Return black top hat of an image.
 
     The black top hat of an image is defined as its morphological closing minus
@@ -577,6 +631,17 @@ def black_tophat(image, footprint=None, out=None):
     out : ndarray, optional
         The array to store the result of the morphology. If None
         is passed, a new array will be allocated.
+    mode : str, optional
+        The `mode` parameter determines how the array borders are handled.
+        Valid modes are: 'reflect', 'constant', 'nearest', 'mirror', 'wrap',
+        'max', 'min', or 'ignore'. See :func:`skimage.morphology.closing`.
+        Default is 'reflect'.
+    cval : scalar, optional
+        Value to fill past edges of input if `mode` is 'constant'. Default
+        is 0.0.
+
+        .. versionadded:: 0.23
+            `mode` and `cval` were added in 0.23.
 
     Returns
     -------
@@ -592,8 +657,8 @@ def black_tophat(image, footprint=None, out=None):
     would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
     effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
     computational cost. Most of the builtin footprints such as
-    ``skimage.morphology.disk`` provide an option to automatically generate a
-    footprint sequence of this type.
+    :func:`skimage.morphology.disk` provide an option to automatically generate
+    a footprint sequence of this type.
 
     See Also
     --------
@@ -607,13 +672,13 @@ def black_tophat(image, footprint=None, out=None):
     --------
     >>> # Change dark peak to bright peak and subtract background
     >>> import numpy as np
-    >>> from skimage.morphology import square
+    >>> from skimage.morphology import footprint_rectangle
     >>> dark_on_gray = np.array([[7, 6, 6, 6, 7],
     ...                          [6, 5, 4, 5, 6],
     ...                          [6, 4, 0, 4, 6],
     ...                          [6, 5, 4, 5, 6],
     ...                          [7, 6, 6, 6, 7]], dtype=np.uint8)
-    >>> black_tophat(dark_on_gray, square(3))
+    >>> black_tophat(dark_on_gray, footprint_rectangle((3, 3)))
     array([[0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0],
            [0, 1, 5, 1, 0],
@@ -622,12 +687,17 @@ def black_tophat(image, footprint=None, out=None):
 
     """
     if out is image:
-        original = image.copy()
-    else:
-        original = image
-    out = closing(image, footprint, out=out)
+        # We need a temporary image
+        closed = closing(image, footprint, mode=mode, cval=cval)
+        if np.issubdtype(closed.dtype, bool):
+            np.logical_xor(closed, out, out=out)
+        else:
+            np.subtract(closed, out, out=out)
+        return out
+
+    out = closing(image, footprint, out=out, mode=mode, cval=cval)
     if np.issubdtype(out.dtype, np.bool_):
-        np.logical_xor(out, original, out=out)
+        np.logical_xor(out, image, out=out)
     else:
-        out -= original
+        out -= image
     return out
